import { BasicColumn, FormSchema } from '@/components/Table';

export const columns: BasicColumn[] = [
  {
    title: '系统名称',
    dataIndex: 'systemName',
    width: 150,
    // onEditRow:true
  },
  {
    title: '英文名称',
    dataIndex: 'themeEngName',
    width: 150,
    // onEditRow:true
  },
  {
    title: '描述',
    dataIndex: 'description',
    width: 150,
    customRender: (text) => text || '-',
    // onEditRow:true
  },
  {
    title: '系统标识',
    dataIndex: 'systemCode',
    width: 150,
    // onEditRow:true
  },
  {
    title: '业务部门',
    dataIndex: 'dept',
    width: 150,
    // onEditRow:true
  },
  {
    title: '负责人',
    dataIndex: 'principal',
    width: 150,
    // onEditRow:true
  },
  {
    title: '紧急联系方式',
    dataIndex: 'urgentContact',
    width: 150,
    // onEditRow:true
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    width: 150,
    // onEditRow:true
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '请输入系统名称/英文名称',
    },
    colProps: { span: 5 },
  },
];
export const physicalModelFormSchema: any[] = [
  {
    field: 'systemName',
    label: '系统名称',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'themeEngName',
    label: '英文名称',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'systemCode',
    label: '系统标识',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    required: false,
    colProps: { span: 24 },
  },
  {
    field: 'dept',
    label: '业务部门',
    colProps: { span: 24 },
    component: 'TreeSelect',
    required: true,
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'value',
      },
      treeData: [
        {
          label: '部门1',
          value: 'option1',
          children: [
            {
              label: '二级部门1',
              value: 'subOption1-1',
            },
            {
              label: '二级部门2',
              value: 'subOption1-2',
            },
          ],
        },
        {
          label: '部门2',
          value: 'option2',
          children: [
            {
              label: '二级部门3',
              value: 'subOption2-1',
            },
            {
              label: '二级部门4',
              value: 'subOption2-2',
            },
          ],
        },
      ],
    },
  },
  {
    field: 'principal',
    label: '负责人',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        {
          label: '用户1',
          value: '用户1',
        },
        {
          label: '用户2',
          value: '用户2',
        },
        {
          label: '创建人1',
          value: '创建人1',
        },
      ],
    },
    colProps: { span: 24 },
  },
  {
    field: 'urgentContact',
    label: '紧急联系方式',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
];

/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'themeFather',
    label: '父级主题域',
    colProps: { span: 24 },
    component: 'TreeSelect',
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'value',
      },
      treeData: [
        {
          label: '一级主题域1',
          value: 'option1',
          children: [
            {
              label: '二级主题域1',
              value: 'subOption1-1',
            },
            {
              label: '二级主题域2',
              value: 'subOption1-2',
            },
          ],
        },
        {
          label: '一级主题域2',
          value: 'option2',
          children: [
            {
              label: '二级主题域3',
              value: 'subOption2-1',
            },
            {
              label: '二级主题域4',
              value: 'subOption2-2',
            },
          ],
        },
      ],
    },
  },
];
export const detailColumns: BasicColumn[] = [
  {
    title: '属性名称',
    dataIndex: 'name',
    width: 150,
  },
  {
    title: '描述',
    dataIndex: 'description',
    width: 150,
  },
  {
    title: '属性英文名',
    dataIndex: 'englishName',
    width: 150,
  },
  {
    title: '是否必填',
    dataIndex: 'isWrite',
    width: 150,
    customRender: ({ record }) => (record.isWrite === '1' ? '是' : '否'),
  },
  {
    title: '是否显示',
    dataIndex: 'isShow',
    width: 150,
    customRender: ({ record }) => (record.isShow === '1' ? '是' : '否'),
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 200,
    customRender: ({ record }) => {
      const typeMap = {
        '1': '字符串',
        '2': '布尔',
        '3': '整型',
        '4': '浮点型',
      };
      return typeMap[record.type];
    },
  },
];
